pub fn cleanup_old_sessions(max_age: Duration) -> WorkspaceResult<usize>Expand description
Clean up old session workspaces that are older than the specified duration
pub fn cleanup_old_sessions(max_age: Duration) -> WorkspaceResult<usize>Clean up old session workspaces that are older than the specified duration